@@ -1,7 +1,7 @@
 package Perinci::Sub::Complete;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.85'; # VERSION
+our $DATE = '2016-08-03'; # DATE
+our $VERSION = '0.86'; # VERSION
 
 use 5.010001;
 use strict;
@@ -121,10 +121,10 @@ sub complete_from_schema {
     my $words;
     eval {
         if (my $xcomp = $cs->{'x.completion'}) {
-            require Module::Path::More;
+            require Module::Installed::Tiny;
             my $mod = "Perinci::Sub::XCompletion::$xcomp->[0]";
             my $comp;
-            if (Module::Path::More::module_path(module=>$mod)) {
+            if (Module::Installed::Tiny::module_installed($mod)) {
                 $log->tracef("[comp][periscomp] loading module %s ...", $mod);
                 my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm";
                 require $mod_pm;
@@ -387,9 +387,9 @@ sub complete_arg_val {
             }
             my $xcomp = $arg_spec->{'x.completion'};
             if ($xcomp) {
-                require Module::Path::More;
+                require Module::Installed::Tiny;
                 my $mod = "Perinci::Sub::XCompletion::$xcomp->[0]";
-                if (Module::Path::More::module_path(module=>$mod)) {
+                if (Module::Installed::Tiny::module_installed($mod)) {
                     $log->tracef("[comp][periscomp] loading module %s ...", $mod);
                     my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm";
                     require $mod_pm;
@@ -403,9 +403,9 @@ sub complete_arg_val {
             }
             my $ent = $arg_spec->{'x.schema.entity'};
             if ($ent) {
-                require Module::Path::More;
+                require Module::Installed::Tiny;
                 my $mod = "Perinci::Sub::ArgEntity::$ent";
-                if (Module::Path::More::module_path(module=>$mod)) {
+                if (Module::Installed::Tiny::module_installed($mod)) {
                     $log->tracef("[comp][periscomp] loading module %s ...", $mod);
                     my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm";
                     require $mod_pm;
@@ -538,9 +538,9 @@ sub complete_arg_elem {
             }
             my $xelcomp = $arg_spec->{'x.element_completion'};
             if ($xelcomp) {
-               require Module::Path::More;
+               require Module::Installed::Tiny;
                 my $mod = "Perinci::Sub::XCompletion::$xelcomp->[0]";
-                if (Module::Path::More::module_path(module=>$mod)) {
+               if (Module::Installed::Tiny::module_installed($mod)) {
                     $log->tracef("[comp][periscomp] loading module %s ...", $mod);
                     my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm";
                     require $mod_pm;
@@ -554,9 +554,9 @@ sub complete_arg_elem {
             }
             my $ent = $arg_spec->{'x.schema.element_entity'};
             if ($ent) {
-                require Module::Path::More;
+                require Module::Installed::Tiny;
                 my $mod = "Perinci::Sub::ArgEntity::$ent";
-                if (Module::Path::More::module_path(module=>$mod)) {
+                if (Module::Installed::Tiny::module_installed($mod)) {
                     $log->tracef("[comp][periscomp] loading module %s ...", $mod);
                     my $mod_pm = $mod; $mod_pm =~ s!::!/!g; $mod_pm .= ".pm";
                     require $mod_pm;
@@ -989,7 +989,7 @@ Perinci::Sub::Complete - Complete command-line argument using Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.85 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2016-07-22.
+This document describes version 0.86 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2016-08-03.
 
 =head1 SYNOPSIS
 
